@@ -7,23 +7,10 @@ from typing_extensions import Literal, NotRequired, Protocol, TypedDict, TypeVar
 
 from .hybrid_observer import HybridObservable
 
-# Basic types
-Callback = Union[
-    Callable[..., Any],
-    Callable[..., Coroutine[Any, Any, Any]],
-]
-
-JSONValue = Union[str, int, float, bool, dict[str, Any], list[Any]]
-JSONObject = dict[str, JSONValue]
-JSONArray = list[JSONValue]
-Path = Union[list[Union[int, str]], int, str]
-
+# Literals
 CameraType = Literal["camera", "doorbell"]
-
 ZoneType = Literal["intersect", "contain"]
-
 ZoneFilter = Literal["include", "exclude"]
-
 ObjectClass = Literal[
     "person",
     "bicycle",
@@ -107,13 +94,11 @@ ObjectClass = Literal[
     "toothbrush",
     "motion",
 ]
-
 CameraRoles = Literal["high-resolution", "mid-resolution", "low-resolution", "snapshot"]
-Container = Literal["mp4", "mpegts"]
 DecoderFormat = Literal["yuv", "rgb"]
 ImageInputFormat = Literal["yuv", "rgb", "rgba", "gray"]
 ImageOutputFormat = Literal["rgb", "rgba", "gray"]
-CameraExtension = Literal["hub", "prebuffer", "motionDetection", "objectDetection", "audioDetection", "ptz"]
+CameraExtension = Literal["hub", "motionDetection", "objectDetection", "audioDetection", "ptz"]
 CameraFrameWorkerDecoder = Literal["pillow", "wasm", "rust"]
 CameraFrameWorkerResolution = Literal[
     "3840x2160",
@@ -135,6 +120,49 @@ AudioFFmpegCodec = Literal[
 VideoCodec = Literal["H264", "H265", "VP8", "VP9", "AV1", "JPEG", "RAW"]
 VideoFFmpegCodec = Literal["h264", "hevc", "vp8", "vp9", "av1", "mjpeg", "rawvideo"]
 PythonVersion = Literal["3.9", "3.10", "3.11", "3.12"]
+InternalSourceType = Literal["aac", "opus", "pcma"]
+StateNames = Literal["light", "motion", "audio", "doorbell", "siren", "battery", "object"]
+CameraPublicProperties = Literal[
+    "_id",
+    "nativeId",
+    "pluginId",
+    "name",
+    "disabled",
+    "isCloud",
+    "hasLight",
+    "hasSiren",
+    "hasBinarySensor",
+    "hasBattery",
+    "info",
+    "type",
+    "detectionZones",
+    "detectionSettings",
+    "hasAudioDetector",
+    "hasMotionDetector",
+    "hasObjectDetector",
+    "extendedMotionDetector",
+    "hasPtz",
+    "sources",
+    "frameWorkerSettings",
+]
+DeviceManagerEventType = Literal[
+    "cameraSelected",
+    "cameraDeselected",
+]
+JsonSchemaType = Literal["string", "number", "boolean", "object", "array", "button"]
+LoggerLevel = Literal["error", "warn", "info", "debug", "trace", "attention", "success"]
+APIEventType = Literal["finishLaunching", "shutdown"]
+
+# Basic types
+Callback = Union[
+    Callable[..., Any],
+    Callable[..., Coroutine[Any, Any, Any]],
+]
+
+JSONValue = Union[str, int, float, bool, dict[str, Any], list[Any]]
+JSONObject = dict[str, JSONValue]
+JSONArray = list[JSONValue]
+Path = Union[list[Union[int, str]], int, str]
 
 
 # Interfaces as TypedDict
@@ -198,7 +226,7 @@ class ObjectDetectionSettings(TypedDict):
     confidence: float
 
 
-class CameraActivitySettings(TypedDict):
+class CameraDetectionSettings(TypedDict):
     motion: MotionDetectionSettings
     object: ObjectDetectionSettings
 
@@ -223,11 +251,6 @@ class CameraInput(TypedDict):
     internal: bool
 
 
-class PrebufferState(TypedDict, total=False):
-    url: str
-    duration: int
-
-
 class RTPInfo(TypedDict):
     payload: Optional[int]
     codec: str
@@ -339,13 +362,13 @@ class BaseStateWithoutLastEvent(TypedDict):
 
 
 class MotionSetEvent(TypedDict):
-    state: NotRequired[bool]
-    detections: list[Detection]
+    state: bool
+    detections: NotRequired[Optional[list[Detection]]]
 
 
 class AudioSetEvent(TypedDict):
     state: bool
-    db: Optional[float]
+    db: NotRequired[Optional[float]]
 
 
 class ObjectSetEvent(TypedDict):
@@ -362,13 +385,13 @@ class DoorbellSetEvent(TypedDict):
 
 class SirenSetEvent(TypedDict):
     state: bool
-    level: Optional[int]
+    level: NotRequired[Optional[int]]
 
 
 class BatterySetEvent(TypedDict):
     level: int
-    lowBattery: Optional[bool]
-    charging: Optional[bool]
+    lowBattery: NotRequired[Optional[bool]]
+    charging: NotRequired[Optional[bool]]
 
 
 class LightState(BaseState["LightStateWithoutLastEvent"], LightSetEvent):
@@ -556,12 +579,6 @@ class CameraDelegate(Protocol):
     async def snapshot(self) -> Optional[bytes]: ...
 
 
-class CameraPrebufferDelegate(Protocol):
-    async def getPrebufferingState(
-        self, source_name: str, container: Container
-    ) -> Optional[PrebufferState]: ...
-
-
 class CameraPTZDelegate(Protocol):
     async def moveAbsolute(self, pan: float, tilt: float, zoom: float) -> None: ...
     async def moveRelative(self, pan: float, tilt: float, zoom: float) -> None: ...
@@ -571,13 +588,9 @@ class CameraPTZDelegate(Protocol):
 
 class CameraDelegates(TypedDict):
     cameraDelegate: CameraDelegate
-    prebufferDelegate: CameraPrebufferDelegate
     ptzDelegate: CameraPTZDelegate
 
 
-InternalSourceType = Literal["aac", "opus", "pcma"]
-
-
 class CameraBaseSource(Protocol):
     # from CameraInput
     id: str  # _id
@@ -594,7 +607,6 @@ class CameraBaseSource(Protocol):
 
 class CameraDeviceSource(CameraBaseSource, Protocol):
     def get_internal_source(self, type: InternalSourceType) -> "CameraDeviceInternalSource": ...
-    async def get_prebuffering_state(self, container: Container) -> Optional[PrebufferState]: ...
 
 
 class CameraDeviceInternalSource(CameraBaseSource, Protocol):
@@ -655,8 +667,7 @@ class BaseCamera(TypedDict):
     info: CameraInformation
     type: CameraType
     snapshotTTL: int
-    activityZones: list[CameraZone]
-    activitySettings: CameraActivitySettings
+    detectionSettings: CameraDetectionSettings
     frameWorkerSettings: CameraFrameWorkerSettings
 
 
@@ -666,13 +677,10 @@ class Camera(BaseCamera):
     hasObjectDetector: bool
     extendedMotionDetector: bool
     hasPtz: bool
-    hasPrebuffer: bool
     sources: list[CameraInput]
-    activityZones: list[DetectionZone]  # type: ignore
+    detectionZones: list[DetectionZone]
 
 
-StateNames = Literal["light", "motion", "audio", "doorbell", "siren", "battery", "object"]
-
 StateValue = Union[
     LightState,
     MotionState,
@@ -704,32 +712,6 @@ class CameraConfigInputSettingsPartial(TypedDict, total=False):
     urls: list[str]
 
 
-CameraPublicProperties = Literal[
-    "_id",
-    "nativeId",
-    "pluginId",
-    "name",
-    "disabled",
-    "isCloud",
-    "hasLight",
-    "hasSiren",
-    "hasBinarySensor",
-    "hasBattery",
-    "info",
-    "type",
-    "activityZones",
-    "activitySettings",
-    "hasAudioDetector",
-    "hasMotionDetector",
-    "hasObjectDetector",
-    "extendedMotionDetector",
-    "hasPrebuffer",
-    "hasPtz",
-    "sources",
-    "frameWorkerSettings",
-]
-
-
 @runtime_checkable
 class CameraDevice(Protocol):
     @property
@@ -771,11 +753,9 @@ class CameraDevice(Protocol):
     @property
     def has_ptz(self) -> bool: ...
     @property
-    def has_prebuffer(self) -> bool: ...
+    def detection_zones(self) -> list[DetectionZone]: ...
     @property
-    def activity_zones(self) -> list[DetectionZone]: ...
-    @property
-    def activity_settings(self) -> CameraActivitySettings: ...
+    def detection_settings(self) -> CameraDetectionSettings: ...
     @property
     def frameworker_settings(self) -> CameraFrameWorkerSettings: ...
     @property
@@ -836,9 +816,7 @@ class CameraDevice(Protocol):
     def on_state_change(
         self, state_name: Literal["object"]
     ) -> HybridObservable[CameraStateChangedObject[ObjectState]]: ...
-    def on_state_change(  # type: ignore
-        self, state_name: StateNames
-    ) -> HybridObservable[CameraStateChangedObject[StateValue]]: ...
+    def on_state_change(self, state_name: Any) -> Any: ...
 
     def on_property_change(
         self, property: Union[CameraPublicProperties, list[CameraPublicProperties]]
@@ -873,8 +851,6 @@ class CameraDevice(Protocol):
     @overload
     def set_delegate(self, name: Literal["cameraDelegate"], delegate: CameraDelegate) -> None: ...
     @overload
-    def set_delegate(self, name: Literal["prebufferDelegate"], delegate: CameraPrebufferDelegate) -> None: ...
-    @overload
     def set_delegate(self, name: Literal["ptzDelegate"], delegate: CameraPTZDelegate) -> None: ...
 
     async def connect(self) -> None: ...
@@ -957,11 +933,6 @@ CameraDeselectedCallback = Union[
     Callable[[str, CameraExtension], Coroutine[None, None, None]],
 ]
 
-DeviceManagerEventType = Literal[
-    "cameraSelected",
-    "cameraDeselected",
-]
-
 
 @runtime_checkable
 class DeviceManager(Protocol):
@@ -1015,13 +986,10 @@ class CoreManager(Protocol):
 # Schema related types and interfaces
 PluginConfig = dict[str, Any]
 
-JsonSchemaType = Literal["string", "number", "boolean", "object", "array", "button"]
-
 J = TypeVar("J")
 
 
 class JsonBaseSchema(TypedDict, Generic[J]):
-    type: JsonSchemaType
     key: NotRequired[str]
     title: NotRequired[str]
     description: NotRequired[str]
@@ -1041,7 +1009,7 @@ class JsonBaseSchema(TypedDict, Generic[J]):
 
 
 class JsonSchemaString(JsonBaseSchema[str]):
-    type: Literal["string"]  # type: ignore
+    type: Literal["string"]
     format: NotRequired[
         Literal["date-time", "date", "time", "email", "uuid", "ipv4", "ipv6", "password", "qrCode", "image"]
     ]
@@ -1050,41 +1018,43 @@ class JsonSchemaString(JsonBaseSchema[str]):
 
 
 class JsonSchemaNumber(JsonBaseSchema[float]):
-    type: Literal["number"]  # type: ignore
+    type: Literal["number"]
     minimum: NotRequired[float]
     maximum: NotRequired[float]
     step: NotRequired[float]
 
 
 class JsonSchemaBoolean(JsonBaseSchema[bool]):
-    type: Literal["boolean"]  # type: ignore
+    type: Literal["boolean"]
 
 
 class JsonSchemaEnum(JsonBaseSchema[str]):
-    type: Literal["string"]  # type: ignore
+    type: Literal["string"]
     enum: list[str]
     multiple: NotRequired[bool]
 
 
 class JsonSchemaObject(JsonBaseSchema[Any]):
-    type: Literal["object"]  # type: ignore
+    type: Literal["object"]
     opened: NotRequired[bool]
     properties: NotRequired["JsonSchemaForm"]
 
 
 class JsonSchemaArray(JsonBaseSchema[Any]):
-    type: Literal["array"]  # type: ignore
+    type: Literal["array"]
     opened: NotRequired[bool]
     items: NotRequired["JsonSchema"]
 
 
 class JsonSchemaButton(JsonBaseSchema[Any]):
-    type: Literal["button"]  # type: ignore
+    type: Literal["button"]
+    color: NotRequired[str]
 
 
 class JsonSchemaObjectButton(TypedDict):
     label: str
     onSubmit: str
+    color: NotRequired[str]
 
 
 class JsonSchemaObjectWithButtons(JsonSchemaObject):
@@ -1186,9 +1156,6 @@ class AudioDetectionPlugin(BasePlugin):
     ) -> AudioDetectionPluginResponse: ...
 
 
-LoggerLevel = Literal["error", "warn", "info", "debug", "trace", "attention", "success"]
-
-
 @runtime_checkable
 class LoggerService(Protocol):
     def log(self, *args: Any) -> None: ...
@@ -1200,8 +1167,6 @@ class LoggerService(Protocol):
     def success(self, *args: Any) -> None: ...
 
 
-APIEventType = Literal["finishLaunching", "shutdown"]
-
 PA = TypeVar("PA", bound="CameraStorage[Any]", default="CameraStorage[Any]")
 
 
